@@ -8,12 +8,14 @@ class inputconf:
 	if os.name == "nt":
 		CFG_FILENAME = "./input.cfg"
 		MOUSE_SETTING_FILE = "C:\\python24\\pdaxrom\\misc\\x11"
+		MOUSE_SETTING_FILE_NEW = "C:\\python24\\pdaxrom\\misc\\x11mousebutts"
 		MODMAP_FILE = "C:\\python24\\pdaxrom\\misc\\userdefined.xmodmap"
 		KERNELMAP_FILE = "C:\\python24\\pdaxrom\\misc\\kernel.map"
 		RC_XML = "C:\\python24\\pdaxrom\\misc\\rc.xml"
 	else:
 		CFG_FILENAME = os.environ['HOME'] + "/Choices/input.cfg"
 		MOUSE_SETTING_FILE = "/etc/sysconfig/x11"
+		MOUSE_SETTING_FILE_NEW = "/etc/sysconfig/x11mousebutts"
 		MODMAP_FILE = "/etc/X11/kb/userdefined.xmodmap"
 		KERNELMAP_FILE = "/etc/sysconfig/keyboard/kernel.map"
 		RC_XML = "/etc/xdg/openbox/rc.xml"
@@ -479,16 +481,27 @@ class inputconf:
 	
 	# Create X mouse mapping
 		output = ""
+		output_new = ""
 		if (self.presshold):
 			output += "X11_RIGHT_MOUSE_BUTTON=hold\n"
+			output_new += "hold_right_button 1\n"
 		else:
 			output += "X11_RIGHT_MOUSE_BUTTON=\"\"\n"
 			output += "X11_RIGHT_MOUSE_BUTTON_MOD=" + str(int(bcb.store.get_data("RMB"))-8) + "\n"
+			output_new += "hold_right_button 0\n"
+			output_new += "right_button " + str(int(bcb.store.get_data("RMB"))) + "\n"
 		
 		output += "X11_MIDDLE_MOUSE_BUTTON_MOD=" + str(int(bcb.store.get_data("MMB"))-8)
+		output_new += "middle_button " + str(int(bcb.store.get_data("MMB"))) + "\n"
+		output_new += "power_button 117\n"
+		
 		f=open(self.MOUSE_SETTING_FILE, "w")
 		f.write(output)
 		f.close()
+
+		f=open(self.MOUSE_SETTING_FILE_NEW, "w")
+		f.write(output_new)
+		f.close()
 		
 		output = "! ------------ User defined keys ------------ \n\n"
 		
